@@ -17,7 +17,8 @@ from mobster.calculate_posteriors import *
 from pyro.util import ignore_jit_warnings
 
 
-def fit_mobster(data, K, tail=1, purity=0.96,alpha_prior_concentration = 5, alpha_prior_rate = 10, number_of_trials_clonal_mean=500.,number_of_trials_k=300.,
+def fit_mobster(data, K, tail=1, purity=0.96, number_of_trials_clonal_mean=500.,number_of_trials_k=300.,
+                alpha_precision_concentration = 5, alpha_precision_rate=0.1,
          prior_lims_clonal=[0.1, 100000.], prior_lims_k=[0.1, 100000.], stopping = ELBO_stopping_criteria, lr = 0.05,
                 max_it = 5000, e = 0.001, compile = False, CUDA = False, seed = 3, lrd_gamma = 0.1):
 
@@ -51,8 +52,8 @@ def fit_mobster(data, K, tail=1, purity=0.96,alpha_prior_concentration = 5, alph
         'K' : K,
         'tail' : tail,
         'purity' : purity,
-        'alpha_prior_concentration' : alpha_prior_concentration,
-        'alpha_prior_rate' : alpha_prior_rate,
+        'alpha_precision_concentration' : alpha_precision_concentration,
+        'alpha_precision_rate' : alpha_precision_rate,
         'number_of_trials_clonal_mean' : number_of_trials_clonal_mean,
         'number_of_trials_k' : number_of_trials_k,
         'prior_lims_clonal' : prior_lims_clonal,
