@@ -21,9 +21,9 @@ theo_allele_list = {
 }
 
 theo_clonal_means_list = {
-    "1:0" : 0.99999,
-    "1:1" : 0.5,
-    "2:0" : torch.tensor([0.5,0.99999]),
+    "1:0" : torch.tensor(0.95),
+    "1:1" : torch.tensor(0.5),
+    "2:0" : torch.tensor([0.5,0.95]),
     "2:1" : torch.tensor([0.333,0.666]),
     "2:2" : torch.tensor([0.25,0.5])
 }
@@ -107,7 +107,6 @@ def format_parameters_for_export_aux(data, params,k, i, theo_clones, counts_clon
     if tail == 1:
         res["tail_shape"] = params['tail_mean'].detach().numpy()
         res["tail_scale"] = np.min(data[k].detach().numpy())
-        res["tail_shape_sd"] = 1/params['tail_sd'].detach().numpy()
         res["tail_noise"] =  1/params['alpha_noise'][i].detach().numpy()
 
     return res
